from django.db import models


class TypographyField(models.TextField):
    def __init__(self, *args, **kwargs):
        self.source = kwargs.pop('source', None)
        self.engine = kwargs.pop("engine", None)
        self.options = kwargs.pop("options", {})
        d = {'editable': False, 'blank': True, 'null': True}
        d.update(kwargs)
        super(TypographyField, self).__init__(*args, **d)



# coding: utf-8
"""A setuptools based setup module.
See:
https://packaging.python.org/en/latest/distributing.html
https://github.com/pypa/sampleproject
"""
from __future__ import unicode_literals
from setuptools import setup, find_packages

from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))
print path.join(here, 'README.md')
# Get the long description from the relevant file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='django_typograph',

    # Versions should comply with PEP440.  For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # https://packaging.python.org/en/latest/single_source_version.html
    version='0.1.1',

    description='Типограф для Django',
    long_description=long_description,

    # The project's main homepage.
    url='https://github.com/pypa/django_typograph',

    # Author details
    author='Xacce',
    author_email='thiscie@gmail.com',

    license='MIT',

    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
    ],

    # What does your project relate to?
    keywords='russian typograph language',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=[],

    # List run-time dependencies here.  These will be installed by pip when
    # your project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/requirements.html
    requires=['django (>= 1.7)', 'progressbar2'],
)
